from typing import Any, Optional

from gcs_cli.commands.storage_gateway._common import make_create_command
from gcs_cli.parsing import (
    azure_blob_options,
    globus_command,
    storage_gateway_create_and_update_params,
)
from gcs_cli.sdk_client.data import AzureBlobStoragePolicies, StorageGatewayDocument
from gcs_cli.services.gcs import AZURE_BLOB_CONNECTOR_ID


@globus_command("azure-blob")
@storage_gateway_create_and_update_params(create=True)
@azure_blob_options(create=True)
@make_create_command
def azure_blob_create(
    *,
    ms_client_id: Optional[str],
    ms_client_secret: Optional[str],
    ms_tenant: Optional[str],
    ms_allow_any_account: Optional[bool],
    azure_storage_account: Optional[str],
    azure_credential_type: Optional[str],
    azure_adls: Optional[bool],
    **kwargs: Any
) -> StorageGatewayDocument:
    """Create a new Azure Blob Storage Gateway"""
    if not azure_adls:
        azure_adls = False

    policies = AzureBlobStoragePolicies(
        client_id=ms_client_id,
        secret=ms_client_secret,
        tenant=ms_tenant,
        account=azure_storage_account,
        auth_type=azure_credential_type or "user",
        adls=azure_adls,
        allow_any_account=ms_allow_any_account,
    )
    return StorageGatewayDocument(
        connector_id=AZURE_BLOB_CONNECTOR_ID, policies=policies, **kwargs
    )
