from __future__ import annotations

from globus_sdk.paging import Paginator

from gcs_cli.helpers import requires_login
from gcs_cli.parsing import globus_command, include_private_policies_opt, page_size_opt
from gcs_cli.prettyprint import FORMAT_TEXT_TABLE, FieldSpec, formatted_print
from gcs_cli.services.gcs import connector_id_to_display_name, get_client


@globus_command("list", short_help="List storage gateways")
@include_private_policies_opt
@requires_login
@page_size_opt
def storage_gateway_list(
    include_private_policies: bool,
    page_size: int | None,
) -> None:
    """
    List all storage gateways on the endpoint the GCS cli is logged into
    """
    client = get_client()

    include = []
    if include_private_policies:
        include = ["private_policies"]

    params = {}
    if page_size:
        params["page_size"] = page_size

    res: Paginator = client.paginated.get_storage_gateway_list(include, **params)

    # output
    fields: FieldSpec = [
        ("Display Name", "display_name"),
        ("ID", "id"),
        ("Connector", lambda x: connector_id_to_display_name(x["connector_id"])),
        ("High Assurance", "high_assurance"),
        ("MFA", lambda x: x.get("require_mfa", False)),
    ]
    formatted_print(res, text_format=FORMAT_TEXT_TABLE, fields=fields)
