from __future__ import annotations

from typing import Optional

import click

from globus_sdk.paging import Paginator

from gcs_cli.commands.user_credentials._common import credential_status
from gcs_cli.helpers import default_identity_id_resolver, requires_login
from gcs_cli.parsing import globus_command, page_size_opt
from gcs_cli.prettyprint import FORMAT_TEXT_TABLE, formatted_print
from gcs_cli.services.gcs import get_client


@globus_command("list", short_help="List all User Credentials on the Endpoint")
@click.option(
    "--include",
    type=click.Choice(choices=["all"]),
    help="Include specific types of credentials in response",
)
@requires_login
@page_size_opt
def cred_list(include: Optional[str], page_size: int | None) -> None:
    """
    Show all User Credentials on the current Endpoint
    """
    client = get_client()
    query_parameters: dict[str, str | int] = {}
    if include:
        query_parameters["include"] = include
    if page_size:
        query_parameters["page_size"] = page_size
    res: Paginator = client.paginated.get_user_credential_list(**query_parameters)
    formatted_print(
        res,
        text_format=FORMAT_TEXT_TABLE,
        fields=[
            ("ID", "id"),
            ("Local Username", "username"),
            ("Username", default_identity_id_resolver.field),
            ("Status", credential_status),
        ],
    )
