# pragma: no cover
from typing import List, Optional, Union
from typing_extensions import (
    Literal,
    TypedDict,
)


from .transfer_documents import NetworkUseName, PrincipalTypeName, ACLPermissionName


class ExpressionIdentityMappingEntryDictBase(TypedDict):
    source: str
    match: str
    output: str


class ExpressionIdentityMappingEntryDict(
    ExpressionIdentityMappingEntryDictBase, total=False
):
    literal: bool


class ExpressionIdentityMappingDict(TypedDict):
    DATA_TYPE: Literal["expression_identity_mapping#1.0.0"]
    mappings: List[ExpressionIdentityMappingEntryDict]


class ExternalIdentityMappingDict(TypedDict):
    DATA_TYPE: Literal["external_identity_mapping#1.0.0"]
    command: List[str]


IdentityMappingDict = Union[ExpressionIdentityMappingDict, ExternalIdentityMappingDict]


class ManagedDomainDict(TypedDict, total=False):
    DATA_TYPE: Literal["domain#1.0.0"]
    domain_name: str
    wildcard: bool
    certificate: str
    certificate_chain: Optional[str]
    private_key: str


class UnmanagedDomainDict(TypedDict, total=False):
    DATA_TYPE: Literal["domain#1.0.0"]
    domain_name: str
    wildcard: bool
    certificate_path: str
    certificate_chain_path: Optional[str]
    private_key_path: str


DomainDict = Union[ManagedDomainDict, UnmanagedDomainDict]


class PathRestrictionsDict(TypedDict):
    DATA_TYPE: Literal["path_restrictions#1.0.0"]
    read: List[str]
    read_write: List[str]
    none: List[str]


class SharingPoliciesDict(TypedDict, total=False):
    DATA_TYPE: Literal["sharing_policy#1.0.0"]
    id: str
    collection_id: str
    sharing_restrict_paths: PathRestrictionsDict
    users: Optional[List[str]]


class StorageGatewayDict(TypedDict, total=False):
    DATA_TYPE: Literal["storage_gateway#1.1.0"]
    id: str
    display_name: str
    high_assurance: bool
    authentication_timeout_mins: int
    allowed_domains: List[str]
    identity_mappings: Optional[List[IdentityMappingDict]]
    users_allow: Optional[List[str]]
    users_deny: Optional[List[str]]
    restrict_paths: Optional[PathRestrictionsDict]
    require_mfa: bool


class _MetadataDict(TypedDict, total=False):
    display_name: str
    organization: str
    department: str
    keywords: List[str]
    description: str
    contact_email: str
    contact_info: str
    info_link: str


class EndpointDict(_MetadataDict):
    DATA_TYPE: Literal["endpoint#1.0.0"]
    public: bool
    subscription_id: Optional[str]
    network_use: Optional[NetworkUseName]
    max_concurrency: Optional[int]
    preferred_concurrency: Optional[int]
    max_parallelism: Optional[int]
    preferred_parallelism: Optional[int]
    allow_udt: bool


class MappedCollectionDict(_MetadataDict):
    DATA_TYPE: Literal["collection#1.4.0"]
    domain_name: str
    collection_type: Literal["mapped"]
    identity_id: str
    storage_gateway_id: str
    collection_base_path: str
    default_directory: str
    public: bool
    force_encryption: bool
    disable_verify: bool
    high_assurance: bool
    authentication_timeout_mins: int
    allow_guest_collections: bool
    sharing_restrict_paths: Optional[PathRestrictionsDict]

    # 1.1.0 policies
    enable_https: bool
    user_message: str
    user_message_link: str

    # 1.2.0 policies
    sharing_users_allow: Optional[List[str]]
    sharing_users_deny: Optional[List[str]]

    # 1.3.0 policies
    domain: DomainDict

    # 1.4.0 policies
    force_verify: bool
    require_mfa: bool


RoleName = Union[
    Literal["owner"],
    Literal["administrator"],
    Literal["access_manager"],
    Literal["activity_manager"],
    Literal["activity_monitor"],
    Literal["access_monitor"],
]


class RoleDict(TypedDict, total=False):
    DATA_TYPE: Literal["role#1.0.0"]
    id: str
    principal: str
    collection: Optional[str]
    role: RoleName


class ACLDict(TypedDict):
    DATA_TYPE: Literal["access"]
    role_id: Literal[None]
    role_type: Literal[None]
    principal_type: Optional[PrincipalTypeName]
    principal: Optional[str]
    path: Optional[str]
    permissions: Optional[ACLPermissionName]


class UserCredentialDict(TypedDict, total=False):
    DATA_TYPE: Literal["user_credential#1.0.0"]
    id: str
    identity_id: str
    storage_gateway_id: str
    username: str
    display_name: str
    invalid: bool
    provisioned: bool
    deleted: bool


class GuestCollectionDict(_MetadataDict):
    DATA_TYPE: Literal["collection#1.4.0"]
    domain_name: str
    collection_type: Literal["guest"]
    identity_id: str
    storage_gateway_id: str
    mapped_collection_id: str
    collection_base_path: str
    default_directory: str
    public: bool
    force_encryption: bool
    disable_verify: bool
    high_assurance: bool
    authentication_timeout_mins: int

    # 1.1.0 policies
    enable_https: bool
    user_message: str
    user_message_link: str

    # 1.3.0 policies
    domain: DomainDict

    # 1.4.0 policies
    force_verify: bool
    require_mfa: bool


BLACKPEARL_CONNECTOR_ID_LITERAL = Literal["7e3f3f5e-350c-4717-891a-2f451c24b0d4"]
BLACKPEARL_CONNECTOR_ID: BLACKPEARL_CONNECTOR_ID_LITERAL = (
    "7e3f3f5e-350c-4717-891a-2f451c24b0d4"
)


class BlackPearlStorageGatewayPoliciesDict(TypedDict, total=False):
    DATA_TYPE: Literal["blackpearl_storage_policies#1.0.0"]
    s3_endpoint: Optional[str]
    bp_access_id_file: Optional[str]


class BlackPearlStorageGatewayDict(StorageGatewayDict, total=False):
    connector_id: BLACKPEARL_CONNECTOR_ID_LITERAL
    policies: Optional[BlackPearlStorageGatewayPoliciesDict]


class BlackPearlCollectionPoliciesDict(TypedDict, total=False):
    DATA_TYPE: Literal["blackpearl_collection_policies#1.0.0"]
    sharing_groups_allow: List[str]
    sharing_groups_deny: List[str]


class BlackPearlMappedCollectionDict(MappedCollectionDict, total=False):
    policies: BlackPearlCollectionPoliciesDict


class BlackPearlUserCredentialPoliciesDict(TypedDict, total=False):
    DATA_TYPE: Literal["blackpearl_user_credential_policies#1.0.0"]
    access_id: Optional[str]
    secret_key: Optional[str]


class BlackPearlUserCredentialDict(UserCredentialDict, total=False):
    connector_id: BLACKPEARL_CONNECTOR_ID_LITERAL
    policies: BlackPearlUserCredentialPoliciesDict


class BlackPearlGuestCollectionDict(GuestCollectionDict):
    policies: BlackPearlCollectionPoliciesDict


HPSS_CONNECTOR_ID_LITERAL = Literal["fb656a17-0f69-4e59-95ff-d0a62ca7bdf5"]
HPSS_CONNECTOR_ID: HPSS_CONNECTOR_ID_LITERAL = "fb656a17-0f69-4e59-95ff-d0a62ca7bdf5"


class HPSSStorageGatewayPoliciesDict(TypedDict, total=False):
    DATA_TYPE: Literal["hpss_storage_policies#1.1.0"]
    authentication_mech: Optional[str]
    authenticator: Optional[str]
    login_name: Optional[str]
    uda_checksum: Optional[bool]


class HPSSStorageGatewayDict(StorageGatewayDict, total=False):
    connector_id: HPSS_CONNECTOR_ID_LITERAL
    policies: Optional[HPSSStorageGatewayPoliciesDict]


class HPSSCollectionPoliciesDict(TypedDict, total=False):
    DATA_TYPE: Literal["hpss_collection_policies#1.0.0"]
    sharing_groups_allow: List[str]
    sharing_groups_deny: List[str]


class HPSSMappedCollectionDict(MappedCollectionDict, total=False):
    policies: HPSSCollectionPoliciesDict


class HPSSUserCredentialPoliciesDict(TypedDict, total=False):
    DATA_TYPE: Literal["hpss_user_credential_policies#1.0.0"]


class HPSSUserCredentialDict(UserCredentialDict, total=False):
    connector_id: HPSS_CONNECTOR_ID_LITERAL
    policies: HPSSUserCredentialPoliciesDict


class HPSSGuestCollectionDict(GuestCollectionDict):
    policies: HPSSCollectionPoliciesDict


POSIX_CONNECTOR_ID_LITERAL = Literal["145812c8-decc-41f1-83cf-bb2a85a2a70b"]
POSIX_CONNECTOR_ID: POSIX_CONNECTOR_ID_LITERAL = "145812c8-decc-41f1-83cf-bb2a85a2a70b"


class PosixStorageGatewayPoliciesDict(TypedDict, total=False):
    DATA_TYPE: Literal["posix_storage_policies#1.0.0"]
    groups_allow: Optional[List[str]]
    groups_deny: Optional[List[str]]


class PosixStorageGatewayDict(StorageGatewayDict, total=False):
    connector_id: Literal["145812c8-decc-41f1-83cf-bb2a85a2a70b"]
    policies: Optional[PosixStorageGatewayPoliciesDict]


class PosixCollectionPoliciesDict(TypedDict, total=False):
    DATA_TYPE: Literal["posix_collection_policies#1.1.0"]
    sharing_groups_allow: List[str]
    sharing_groups_deny: List[str]


class PosixMappedCollectionDict(MappedCollectionDict, total=False):
    policies: PosixCollectionPoliciesDict


class PosixUserCredentialPoliciesDict(TypedDict, total=False):
    DATA_TYPE: Literal["posix_user_credential_policies#1.0.0"]


class PosixUserCredentialDict(UserCredentialDict, total=False):
    connector_id: POSIX_CONNECTOR_ID_LITERAL
    policies: PosixUserCredentialPoliciesDict


class PosixGuestCollectionDict(GuestCollectionDict):
    policies: PosixCollectionPoliciesDict


S3_CONNECTOR_ID_LITERAL = Literal["7643e831-5f6c-4b47-a07f-8ee90f401d23"]
S3_CONNECTOR_ID: S3_CONNECTOR_ID_LITERAL = "7643e831-5f6c-4b47-a07f-8ee90f401d23"


class S3StorageGatewayPoliciesDict(TypedDict, total=False):
    DATA_TYPE: Literal["s3_storage_policies#1.0.0"]
    s3_endpoint: str
    s3_buckets: List[str]
    s3_user_credential_required: bool


class S3StorageGatewayDict(StorageGatewayDict, total=False):
    connector_id: S3_CONNECTOR_ID_LITERAL
    policies: Optional[S3StorageGatewayPoliciesDict]


class S3CollectionPoliciesDict(TypedDict, total=False):
    DATA_TYPE: Literal["s3_collection_policies#1.0.0"]


class S3MappedCollectionDict(MappedCollectionDict, total=False):
    policies: S3CollectionPoliciesDict


class S3UserCredentialPoliciesDict(TypedDict, total=False):
    DATA_TYPE: Literal["s3_user_credential_policies#1.0.0"]
    s3_key_id: str
    s3_secret_key: str


class S3UserCredentialDict(UserCredentialDict, total=False):
    connector_id: S3_CONNECTOR_ID_LITERAL
    policies: S3UserCredentialPoliciesDict


class S3GuestCollectionDict(GuestCollectionDict):
    policies: S3CollectionPoliciesDict


CEPH_CONNECTOR_ID_LITERAL = Literal["1b6374b0-f6a4-4cf7-a26f-f262d9c6ca72"]
CEPH_CONNECTOR_ID: CEPH_CONNECTOR_ID_LITERAL = "1b6374b0-f6a4-4cf7-a26f-f262d9c6ca72"


class CephStorageGatewayPoliciesDict(TypedDict, total=False):
    DATA_TYPE: Literal["ceph_storage_policies#1.0.0"]
    s3_endpoint: str
    s3_buckets: List[str]
    ceph_admin_key_id: str
    ceph_admin_secret_key: str


class CephStorageGatewayDict(StorageGatewayDict, total=False):
    connector_id: CEPH_CONNECTOR_ID_LITERAL
    policies: Optional[CephStorageGatewayPoliciesDict]


class CephCollectionPoliciesDict(TypedDict, total=False):
    DATA_TYPE: Literal["ceph_collection_policies#1.0.0"]


class CephMappedCollectionDict(MappedCollectionDict, total=False):
    policies: CephCollectionPoliciesDict


class CephUserCredentialPoliciesDict(TypedDict, total=False):
    DATA_TYPE: Literal["ceph_user_credential_policies#1.0.0"]


class CephUserCredentialDict(UserCredentialDict, total=False):
    connector_id: CEPH_CONNECTOR_ID_LITERAL
    policies: CephUserCredentialPoliciesDict


class CephGuestCollectionDict(GuestCollectionDict):
    policies: CephCollectionPoliciesDict
