from __future__ import annotations

import typing as t

from typing_extensions import TypedDict

from globus.manager.constants import ConfigurationObjectTag

from .connector import Connector
from .decorators import checks_policy_property
from .posix_storage_gateway import PosixStorageGateway


class EnvironmentSettingType(TypedDict):
    name: str
    value: str


class PosixStagingStorageGateway(PosixStorageGateway):
    CONNECTOR_ID = "052be037-7dda-4d20-b163-3077314dc3e6"
    POLICY_DATA_TYPE = "posix_staging_storage_policies#1.0.0"
    POLICY_DATA_TYPES = [POLICY_DATA_TYPE]

    __mapper_args__ = {
        "polymorphic_identity": (
            ConfigurationObjectTag.STORAGE_GATEWAY.name + CONNECTOR_ID
        )
    }

    connector_policy_names = PosixStorageGateway.connector_policy_names + [
        "stage_app",
        "environment",
    ]

    connector = Connector(id=CONNECTOR_ID, display_name="POSIX Staging")

    stage_app = PosixStorageGateway.connector_property("stage_app", required=True)

    @checks_policy_property(prop="stage_app")
    def _check_stage_app(self, value: str):
        if not value:
            raise ValueError("The stage_app property is required for this connector.")

    environment = PosixStorageGateway.connector_property("environment")

    @checks_policy_property(prop="environment")
    def _check_environment(self, value: t.Optional[list[EnvironmentSettingType]]):
        if value:
            for entry in value:
                if "name" not in entry:
                    raise ValueError(
                        "Missing environment variable name in {}".format(entry)
                    )
                elif "value" not in entry:
                    raise ValueError(
                        "Missing environment variable value in {}".format(entry)
                    )

    def __repr__(self):
        return "<PosixStagingStorageGateway {}>".format(self.display_name)
