import json

import marshmallow as ma
from jwcrypto import jwk

from ..api import Schema, data_type, data_type_schema


@data_type("key_chain#1.0.0", private=True)
class KeyChain_1_0_0(Schema):
    """
    Keychain for an Endpoint. This includes the public keys
    for all node keys (including the deployment key) and all
    symmetric data keys
    """

    default_key_id = ma.fields.Str(required=True)
    data_keys = ma.fields.List(ma.fields.Raw, required=True)
    node_keys = ma.fields.List(ma.fields.Raw, required=True)
    serial = ma.fields.Int(required=True, allow_none=False)

    @ma.post_load
    def deserialize_to_model(self, obj, **kwargs):
        res = {
            "default_key_id": ma.utils.get_value(obj, "default_key_id"),
            "data_keys": [
                jwk.JWK(**json.loads(k)) for k in ma.utils.get_value(obj, "data_keys")
            ],
            "node_keys": [
                jwk.JWK(**json.loads(k)) for k in ma.utils.get_value(obj, "node_keys")
            ],
            "serial": ma.utils.get_value(obj, "serial"),
        }
        return res

    @ma.pre_dump
    def serialize_from_model(self, obj, **kwargs):
        res = {
            "default_key_id": ma.utils.get_value(obj, "default_key_id"),
            "data_keys": [
                k.export_symmetric() for k in ma.utils.get_value(obj, "data_keys")
            ],
            "node_keys": [
                k.export_public() for k in ma.utils.get_value(obj, "node_keys")
            ],
            "serial": ma.utils.get_value(obj, "serial"),
        }
        return res


KeyChain = data_type_schema.KeyChain
