import marshmallow as ma

from ..api import (
    PolicySchema,
    collection_policy,
    data_type_schema,
    storage_gateway_policy,
    user_credential_policy,
)

BLACKPEARL_CONNECTOR_ID = "7e3f3f5e-350c-4717-891a-2f451c24b0d4"


@storage_gateway_policy(
    "blackpearl_storage_policies#1.0.0", schema_base_name="BlackPearlStoragePolicies"
)
class BlackPearlStoragePolicies_1_0_0(PolicySchema):
    """
    Connector-specific storage gateway policies for the Blackpearl connector
    """

    s3_endpoint = ma.fields.Url(
        schemes=["http", "https"],
        description="""
        The URL of the S3 endpoint of the BlackPearl appliance
        to use to access collections on this Storage Gateway.
        """,
    )
    bp_access_id_file = ma.fields.Str(
        description="""
        Path to the file which provides mappings from usernames within the
        configured identity domain to the ID and secret associated with the
        user's BlackPearl account
        """
    )
    private = ["bp_access_id_file"]
    connector_id = BLACKPEARL_CONNECTOR_ID


@collection_policy(
    "blackpearl_collection_policies#1.0.0",
    schema_base_name="BlackPearlCollectionPolicies",
)
class BlackPearlCollectionPolicies_1_0_0(PolicySchema):
    """
    Connector-specific collection policies for the BlackPearl connector
    """

    connector_id = BLACKPEARL_CONNECTOR_ID


@user_credential_policy(
    "blackpearl_user_credential_policies#1.0.0",
    schema_base_name="BlackPearlUserCredentialPolicies",
)
class BlackPearlUserCredentialPolicies_1_0_0(PolicySchema):
    """
    Connector-specific user credential policies for the Blackpearl connector
    """

    access_id = ma.fields.String(dump_only=True, description="BlackPearl access id")
    secret_key = ma.fields.String(dump_only=True, description="BlackPearl secret key")
    private = ["secret_key"]
    connector_id = BLACKPEARL_CONNECTOR_ID


BlackPearlCollectionPolicies = data_type_schema.BlackPearlCollectionPolicies
BlackPearlStoragePolicies = data_type_schema.BlackPearlStoragePolicies
BlackPearlUserCredentialPolicies = data_type_schema.BlackPearlUserCredentialPolicies
