import os

import click

from gcs_cli.parsing.command_decorator import globus_command

from .db import Operation, Session, create_app, db, format_result


@globus_command(
    "dump",
    help="Dump the full audit log database to a structured format",
    disable_options=["format", "explicit_host"],
)
@click.option(
    "--verbose",
    "-v",
    help="Show verbose output.",
    is_flag=True,
)
@click.option(
    "--format",
    "-F",
    help="Output format.  json or csv.",
    type=click.Choice(["json", "csv"]),
    default="json",
)
@click.option(
    "--db-path",
    "-d",
    help="Path to the audit database",
    type=click.Path(exists=True, dir_okay=False),
    metavar="PATH",
    show_default=True,
    default="~/.globus/audit-logs.db",
)
def audit_dump(db_path, verbose, format):
    db_path = os.path.expanduser(db_path)
    if not os.path.exists(db_path):
        print(
            "Database {} does not exist.  Run the 'audit load' command first.".format(
                db_path
            )
        )
        exit(1)
    app = create_app(db_path)
    with app.app_context():
        query = db.session.query(Operation).join(Session)
        result = query.order_by(Operation.start_ts).all()
        format_result(result, format=format)
