import typing as t

import click

from gcs_cli.parsing.command_decorator import globus_command

from .utils import options
from .utils.deployment_key import DeploymentKey


@globus_command(
    "cleanup",
    short_help="Clean up a Globus Connect Server endpoint",
    help="Clean up a Globus Connect Server endpoint",
    disable_options=["format", "explicit_host"],
)
@options.deployment_key_option(
    click_path=click.Path(
        dir_okay=False,
        exists=True,
        readable=True,
    ),
    required_fields=(
        ("client_id", options.MISSING_CLIENT_ID_MSG),
        ("secret", options.MISSING_SECRET_MSG),
    ),
    path_arg_name="deployment_key_path",
)
@options.deprecated_client_id_option
@options.deprecated_secret_option
@click.option(
    "--development-appsync",
    help="Use the specified URL and client_id for the appsync service",
    metavar="APPSYNC_URL APPSYNC_CLIENT_ID",
    nargs=2,
    hidden=True,
)
@click.option(
    "--skip-delete-registration",
    help="Do not delete the endpoint's client registration.",
    is_flag=True,
    default=False,
    hidden=True,
)
@click.option(
    "--lost-deployment-node-key",
    help="Do not prompt for missing deployment node key.",
    is_flag=True,
    default=False,
)
@click.option(
    "--agree-to-delete-endpoint",
    help="Do not prompt for confirmation that endpoint will be deleted.",
    is_flag=True,
    default=False,
)
@click.pass_context
def endpoint_cleanup(
    ctx: click.Context,
    deployment_key: DeploymentKey,
    deployment_key_path: str,
    development_appsync: t.Optional[t.Tuple[str, str]],
    skip_delete_registration: bool,
    lost_deployment_node_key: bool,
    agree_to_delete_endpoint: bool,
):
    from .endpoint_cleanup import endpoint_cleanup as ec

    assert deployment_key.client_id is not None
    assert deployment_key.secret is not None

    ec(
        ctx,
        str(deployment_key.client_id),
        deployment_key.secret,
        deployment_key.node_key,
        deployment_key_path,
        development_appsync,
        skip_delete_registration,
        lost_deployment_node_key,
        agree_to_delete_endpoint,
    )
