from __future__ import annotations

import uuid

import click

from gcs_cli.parsing.command_decorator import globus_command

from .utils import options
from .utils.deployment_key import DeploymentKey


@globus_command(
    "convert",
    short_help="Convert a deployment key to the latest version",
    help="Convert a deployment key to the latest version",
    disable_options=["format", "explicit_host"],
)
@options.deployment_key_option(
    click_path=click.Path(exists=False, writable=True),
    path_arg_name="deployment_key_path",
)
@click.option(
    "--client-id",
    "-c",
    help="Auth Client ID for this Globus Connect Server Endpoint",
    required=True,
    type=click.types.UUIDParameterType(),
)
@click.option(
    "--secret",
    "-s",
    envvar="GLOBUS_CLIENT_SECRET",
    help="Secret for the auth client",
    hidden=True,
    hide_input=True,
    prompt=True,
    required=True,
)
@click.option("--verbose", "-v", is_flag=True)
def endpoint_key_convert(
    client_id: uuid.UUID,
    deployment_key: DeploymentKey,
    deployment_key_path: str,
    secret: str,
    verbose: bool,
) -> None:
    from .endpoint_key_convert import endpoint_key_convert as ekc

    return ekc(client_id, deployment_key.node_key, deployment_key_path, secret, verbose)
