"""
globus-connect-server endpoint migrate-uuid
"""
import json
import os
import pwd

import click
from sqlalchemy.exc import OperationalError

import globus.manager.api.models as models
from globus.manager.api.app import make_app
from globus.manager.api.blueprints.utils import update_object
from globus.manager.utils.keychain import NodeKey


def endpoint_migrate_uuid() -> None:
    app = make_app(app_config="globus.manager.api.config.migrate_uuid")
    models.db.init_app(app)

    pwent = pwd.getpwnam("gcsweb")

    if os.getuid() not in [0, pwent.pw_uid]:
        click.echo(
            "This command must be run using the root or gcsweb account.", err=True
        )
        click.get_current_context().exit(1)

    with app.app_context():
        try:
            globus_node_key = NodeKey(
                **json.loads(
                    models.Configuration.query.filter_by(name="node_key").one().value
                )
            )
        except OperationalError:
            raise click.ClickException(
                "This command must be run on a configured GCSv5 node"
            )

        for conf in models.Configuration.query:
            app.config[conf.name.upper()] = conf.value

        app.config["NODE_KEY"] = globus_node_key

        items = app.appsync_client.query_all(id="KEY_CHAIN")
        for item in items:
            app.appsync_client.process_item(item)

        items = app.appsync_client.query_all(id="ENDPOINT")
        for item in items:
            app.appsync_client.process_item(item)

        endpoint = models.Endpoint.query.one()

        update_object(endpoint, models.Endpoint.migrate_endpoint_uuid)
