"""
globus-connect-server node create

The globus-connect-server node create command creates a node UUID and adds
a node key to the GCS endpoint's keychain. It outputs a node configuration
that can be used as an argument to the --import-node command-line option of
globus-connect-server node setup
"""
import click

from gcs_cli.parsing.command_decorator import globus_command

from .utils import options
from .utils.deployment_key import DeploymentKey


@globus_command(
    "create",
    short_help="Create a Globus Connect Server node configuration",
    help="Create a Globus Connect Server node configuration",
    disable_options=["format", "explicit_host"],
)
@options.deployment_key_option(
    click_path=click.Path(
        dir_okay=False,
        exists=True,
        readable=True,
    ),
    required_fields=(
        ("node_key", options.MISSING_NODE_KEY_MSG),
        ("client_id", options.MISSING_CLIENT_ID_MSG),
        ("secret", options.MISSING_SECRET_MSG),
    ),
)
@options.deprecated_client_id_option
@options.deprecated_secret_option
@click.option(
    "--export-node",
    type=click.Path(dir_okay=False, writable=True),
    required=True,
    metavar="NODE_INFO_JSON",
    help="File to write node configuration to for deployment.",
)
def node_create(
    deployment_key: DeploymentKey,
    export_node: str,
) -> None:
    from .node_create import node_create as nc

    assert deployment_key.node_key is not None
    assert deployment_key.client_id is not None
    assert deployment_key.secret is not None

    nc(
        str(deployment_key.client_id),
        deployment_key.secret,
        deployment_key.node_key,
        export_node,
    )
