import json
import os

import click
from flask import current_app
from sqlalchemy.exc import OperationalError

import globus.manager.api.models as models
from globus.manager.api.app import make_app
from globus.manager.scripts.utils.setup_utils import load_keychain
from globus.manager.utils.keychain import NodeKey


def oidc_delete() -> None:
    if os.getuid() != 0:
        click.echo("This command must be run as the root user", err=True)
        click.get_current_context().exit(1)

    app = make_app(app_config="globus.manager.api.config.oidc_cli")
    models.db.init_app(app)

    with app.app_context():
        # Needed by AppSync
        try:
            for conf in models.Configuration.query:
                if conf.name == "node_key":
                    value = NodeKey(**json.loads(conf.value))
                else:
                    value = conf.value
                app.config[conf.name.upper()] = value
        except OperationalError:
            raise click.ClickException(
                "This command must be run on a configured GCSv5 node"
            )

        # Make sure `node setup` has been run
        if "CLIENT_ID" not in app.config:
            raise Exception("This node has not been setup.")

        try:
            # Load the keychain
            load_keychain()

            # Get the endpoint
            endpoint_model = models.Endpoint.query.one()

            if endpoint_model.has_oidc_server:
                endpoint_model.oidc_server.delete()
                endpoint_model.oidc_server.write_config()
                endpoint_model.oidc_server = None
                endpoint_model.refresh_configuration_hash()
                current_app.appsync_client.update_object(endpoint_model)
                models.db.session.add(endpoint_model)
                models.db.session.commit()
                click.echo("OIDC Server removed from this endpoint.")

            elif endpoint_model.has_oidc_registration:
                endpoint_model.oidc_registration.delete()
                endpoint_model.oidc_registration = None
                endpoint_model.refresh_configuration_hash()
                current_app.appsync_client.update_object(endpoint_model)
                models.db.session.add(endpoint_model)
                models.db.session.commit()
                click.echo("OIDC Registration removed from this endpoint.")

            else:
                click.echo("No OIDC configuration found.")
                click.get_current_context().exit(1)

        except Exception as e:
            click.echo("Error while deleting OIDC server: {}".format(str(e)))
