"""Add storage gateway capability flags and mapped collection support

Revision ID: 590e1aea2221
Revises: 1edd71022809
Create Date: 2018-03-20 09:46:11.585584

"""
from alembic import op
import sqlalchemy as sa
import json


# revision identifiers, used by Alembic.
revision = '590e1aea2221'
down_revision = '1edd71022809'
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.add_column('collection', sa.Column('collection_policies', sa.TEXT(), nullable=True))
    op.add_column('connector', sa.Column('allow_mapped_collections', sa.BOOLEAN(), server_default='0', nullable=False))
    op.add_column('storage_gateway', sa.Column('allow_guest_collections', sa.BOOLEAN(), server_default='0', nullable=False))
    op.add_column('storage_gateway', sa.Column('allow_mapped_collections', sa.BOOLEAN(), server_default='0', nullable=False))
    op.add_column('storage_gateway', sa.Column('require_high_assurance', sa.BOOLEAN(), server_default='0', nullable=False))
    # ### end Alembic commands ###
    conn = op.get_bind()
    conn.execute(
        sa.text("""
            UPDATE collection
            SET collection_policies=:policy
            """),
        policy=json.dumps({'public': {'type': 'guest'}}))
    op.execute("""
            UPDATE connector
            SET allow_mapped_collections=0
            WHERE id <> '145812c8-decc-41f1-83cf-bb2a85a2a70b';
            """)
    op.execute("""
            UPDATE connector
            SET allow_mapped_collections=1
            WHERE id = '145812c8-decc-41f1-83cf-bb2a85a2a70b';
            """)
    op.execute("""
        UPDATE storage_gateway
        SET
            allow_mapped_collections=0,
            allow_guest_collections=1,
            require_high_assurance=0;
        """)
    op.execute("""
        CREATE TRIGGER immutable_high_assurance
        BEFORE UPDATE ON storage_gateway
        BEGIN
            SELECT CASE
            WHEN NEW.require_high_assurance <> OLD.require_high_assurance
            THEN
               RAISE (ABORT, 'Immutable attribute require_high_assurance')
            END;
        END;
        """)
    op.execute("""
        CREATE TRIGGER create_restrict_mapped_to_mappable_connectors
        BEFORE INSERT ON storage_gateway
        BEGIN
            SELECT CASE
            WHEN NEW.allow_mapped_collections
                AND NOT (
                    SELECT allow_mapped_collections
                    FROM connector WHERE connector.id = NEW.connector_id)
            THEN
               RAISE (ABORT, 'allow_mapped_collections denied by connector')
            END;
        END;
        """)
    op.execute("""
        CREATE TRIGGER update_restrict_mapped_to_mappable_connectors
        BEFORE UPDATE ON storage_gateway
        BEGIN
            SELECT CASE
            WHEN NEW.allow_mapped_collections
                 AND NOT (
                    SELECT allow_mapped_collections
                    FROM connector WHERE connector.id = NEW.connector_id)
            THEN
               RAISE (ABORT, 'allow_mapped_collections denied by connector')
            END;
        END;
        """)



def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_column('storage_gateway', 'require_high_assurance')
    op.drop_column('storage_gateway', 'allow_mapped_collections')
    op.drop_column('storage_gateway', 'allow_guest_collections')
    op.drop_column('connector', 'allow_mapped_collections')
    op.drop_column('collection', 'collection_policies')
    # ### end Alembic commands ###
